Package 'shinywqbench'

Title: R Shiny App to Calculates Aquatic Life Benchmarks
Description: This package is the user interface to the wqbench R package and allows users to easily access standardized ecotoxicology data for thousands of chemicals. Either a SSD or deterministic method is used to determine the critical toxicity value and assessment factors to compute the aquatic life water quality benchmark for a compound.
Authors: Ayla Pearson [aut] (ORCID: <https://orcid.org/0000-0001-7388-1222>), Angeline Tillmanns [aut, cre], Joe Thorley [ctb] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Province of British Columbia [cph]
Maintainer: Angeline Tillmanns <[email protected]>
License: Apache License (== 2)
Version: 0.3.3
Built: 2026-06-01 05:04:34 UTC
Source: https://github.com/poissonconsulting/shinywqbench

Help Index


Run wqbench Application

Description

This function will launch the wqbench app.

Usage

run_wqbench_app()

Examples

## Not run: 
run_wqbench_app()

## End(Not run)